| fleiss_data | R Documentation |
Fleiss dataset from epitools package examples, with event counts and population per age group in tidy format.
fleiss_data
An object of class tbl_df (inherits from tbl, data.frame) with 60 rows and 4 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.